textps(8)

textps - Text to PostScript translator

Showing IRIX 6.5.7. Unchanged since IRIX 6.5.

     NAME
          textps - Text to PostScript translator

     SYNOPSIS
          /usr/etc/appletalk/textps [options]

     DESCRIPTION
          The textps filter converts text to Postscript.  It accepts
          ASCII text on standard input and sends PostScript language
          to standard output.  The textps filter passes PostScript
          through without changing it.

          The textps filter allows page layout specification, but does
          not cause the text within a page to be rearranged.  Text
          extending beyond the maximum image area, however, is
          truncated.  The output defaults to the Courier typeface.

          K-Spool usually uses textps in the pipeline of the input
          filter of a printer, usually spooldir/psif-printername.

     OPTIONS
          Default page layout and rows/columns are overriden by
          entries from the /etc/printcap file (when the -printer
          option is given).  The Imageable Area (which, by
          implication, resets the default margins) is read from
          SETUP.PPD in the current working directory.  The following
          options will override those settings.

          -col [e]n
               Set the minimum number of columns per page to n. When
               used with the e option, the number of columns is set to
               (exactly) n. Defaults to a minimum of 80.

          -l [e]n
               Set the minimum number of lines per page to n. When
               used with the e option, the number of lines is set to
               (exactly) n. Defaults to a minimum of 66.  This option
               is often passed from lpr, which gets it from the pl
               field in /etc/printcap.

          -length n
               Set the length of the physical page to n inches.
               Defaults to 8.5 inches.

          -w[e] n
               Sets the number of columns in the physical page to n.
               Defaults to 80.  Often passed from lpr, which gets it
               from the pw field.

          -width n
               Set the width of the page to n inches.  Defaults to 11
               inches.
          -m [tblr]n
               Set all of the margins to n inches.  When used with the
               t option, only the top margin is set to n. When used
               with the b option, only the bottom margin is set to n.
               When used with the l option, only the left margin is
               set to n. When used with the r option, only the right
               margin is set to n. Defaults to .25 inches for all
               margins.

          -t n Set tab stops to every n columns.  Defaults to tab
               stops every 8 columns.

          -p n Set the number of pages printed on each piece of
               printer paper.  Only the values 1 and 2 are accepted.
               Defaults to 1 page per printer page.

          -i n Set the indent level (left shift of printout) to n
               columns.  Defaults to 0.

          -W   Set wide margin width (this is .25 inches beyond the
               regular margin).

          -c   Encapsulate the file, even if it is already PostScript.
               Normally, PostScript files are passed through
               unmodified.  This allows printing of PostScript source.
               It is usually passed from lpr when the -l option is
               specified.

          -d   Exclude the PostScript dictionary used by textps from
               the output stream.

          -B   Print underlined text and overstrike characters in
               boldface.

          -C   Print control characters in a readable format.

          -I   Turn OFF using ISOLatin1Encoding in the postscript
               font.

          -P   Print in portrait page layout.  This is the default.

          -L   Print in landscape page layout.

          -n user
               get the imageable area from the SETUP.PPD for the
               specified user.

          -J jobname
               Set the document Title in the PostScript header to
               jobname.

          -V   Set verbose mode.  Print information about the page
               format on standard error.  Includes Postscript commands
               in the output stream to time the print job.

          -printer name
               Read page layout parameters from the /etc/printcap file
               entry for printer name.  The parameters affected by
               this are:  layout orientation, number of virtual pages
               per printed page, exact lines per virtual page, and
               exact columns per virtual page.  Specifying this option
               only resets the default parameters, which will be
               overriden with other command line arguments.

          -help
               Print the list of options to standard error.

          -f font-name
               Set the name of the regular font typeface.  Defaults to
               Courier.  See CAVEATS, below.

          -F font-name
               Set the name of the Bold font typeface.  Defaults to
               Courier-Bold.  See CAVEATS, below.

     PAPER SIZES
          If you are using paper other than letter, you will need to
          adjust the width and length options to correspond to the new
          size.  The following table gives the values for some common
          types of paper.

                        letter    legal      A4
               width     8.5       8.5       8.25
               length   11.0      14.0      11.66


     EXAMPLES
          To print the file 'somefile' with wide margins.
               cat somefile | textps -W | lpr

          To print the file 'somefile' on legal sized paper in
          landscape layout:
               cat somefile | textps -w 8.5 -l 14.0 -m 0.75 -L | lpr


     DIAGNOSTICS
          Diagnostics and error conditions are sent to standard error.

     CAVEATS
          The textps filter only works with fixed width fonts.  The -f
          and -F options will not function correctly when a non-fixed
          width font is specified.  The existence of a font is not
          verified until the output is executed by a PostScript
          device.  The font selection options are not listed by the
          - - option.

     SEE ALSO
          psf(1m)